SystemOrganization addCategory: #ConfigurationOfIce!

Object subclass: #ConfigurationOfIce
	instanceVariableNames: 'project username password'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfIce'!

!ConfigurationOfIce class methodsFor: 'private' stamp: 'EstebanLorenzano 2/2/2011 15:44'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfIce class methodsFor: 'private' stamp: 'EstebanLorenzano 2/2/2011 15:44'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
					"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfIce class methodsFor: 'metacello tool support' stamp: 'EstebanLorenzano 2/2/2011 15:44'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfIce class methodsFor: 'metacello tool support' stamp: 'EstebanLorenzano 2/2/2011 15:44'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfIce class methodsFor: 'loading' stamp: 'EstebanLorenzano 2/2/2011 15:44'!
load
	"self load"

	^self project stableVersion load! !

!ConfigurationOfIce class methodsFor: 'loading' stamp: 'NicolasPasserini 2/7/2012 17:06'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfIce class methodsFor: 'metacello tool support' stamp: 'EstebanLorenzano 2/2/2011 15:44'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfIce class methodsFor: 'accessing' stamp: 'EstebanLorenzano 2/2/2011 15:44'!
project

	^self new project! !

!ConfigurationOfIce class methodsFor: 'unloading Metacello' stamp: 'EstebanLorenzano 2/2/2011 15:44'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfIce methodsFor: 'baselines' stamp: 'EstebanLorenzano 2/2/2011 15:47'!
baseline01: spec
	<version: '0.1-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'Initial baseline'.
		spec repository: 'http://squeaksource.com/Feeling' 
			username: self username 
			password: self password.
			
		spec project: 'Glamour' with: [
			spec
				className: 'ConfigurationOfGlamour';
				file: 'ConfigurationOfGlamour';
				repository: 'http://www.squeaksource.com/Glamour' ].
		
		spec package: 'Filesystem' with: [ 
			spec repository: 'http://source.lukas-renggli.ch/fs' ].
		spec package: 'Ice-Core' with: [
			spec requires: 'Filesystem' ].
		spec package: 'Ice-Tests' with: [ 
			spec requires: 'Ice-Core' ]. 
		spec package: 'Ice-Glamour' with: [
			spec requires: #('Glamour' 'Ice-Core') ].
		
		spec group: 'Core' with: #('Filesystem' 'Ice-Core').
		spec group: 'Tests' with: #('Ice-Tests').
		spec group: 'GlamourGUI' with: #('Ice-Glamour').
		spec group: 'ALL' with: #('Core' 'Tests' 'GlamourGUI').
		spec group: 'default' with: #('Core' 'Tests') ].! !

!ConfigurationOfIce methodsFor: 'baselines' stamp: 'DeboraFortini 9/8/2011 19:40'!
baseline02: spec
	<version: '0.2-baseline'>
	"This  baseline works for Pharo-1.3"
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'Initial baseline'.
		spec repository: 'http://squeaksource.com/Feeling' 
			username: self username 
			password: self password.
			
		spec project: 'Glamour' with: [
			spec
				className: 'ConfigurationOfGlamour';
				file: 'ConfigurationOfGlamour';
				repository: 'http://www.squeaksource.com/Glamour' ].
		
		spec package: 'FS-Core' with: [
			spec repository: 'http://ss3.gemstone.com/ss/Pharo14' ].
		spec package: 'FS-Disk' with: [
			spec repository: 'http://ss3.gemstone.com/ss/Pharo14' ].
		spec package: 'FS-Memory' with: [
			spec repository: 'http://ss3.gemstone.com/ss/Pharo14' ].
	
		spec package: 'Ice-Core' with: [
			spec requires: #('FS-Core' 'FS-Disk' 'FS-Memory') ].
		spec package: 'Ice-Tests' with: [ 
			spec requires: 'Ice-Core' ]. 
		spec package: 'Ice-Glamour' with: [
			spec requires: #('Glamour' 'Ice-Core') ].
		
		spec group: 'Core' with: #('FS-Core' 'FS-Disk' 'FS-Memory' 'Ice-Core').
		spec group: 'Tests' with: #('Ice-Tests').
		spec group: 'GlamourGUI' with: #('Ice-Glamour').
		spec group: 'ALL' with: #('Core' 'Tests' 'GlamourGUI').
		spec group: 'default' with: #('Core' 'Tests') ].! !

!ConfigurationOfIce methodsFor: 'baselines' stamp: 'NicolasPasserini 2/11/2012 15:30'!
baseline03: spec
	<version: '0.3-baseline'>
	"This  baseline works for Pharo-1.3"
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'Initial baseline'.
		spec repository: 'http://squeaksource.com/Feeling' 
			username: self username 
			password: self password.
			
		spec project: 'Glamour' with: [
			spec
				className: 'ConfigurationOfGlamour';
				file: 'ConfigurationOfGlamour';
				repository: 'http://www.squeaksource.com/Glamour' ].
		
		spec project: 'FileSystem' with: [
			spec 
				repository: 'http://www.squeaksource.com/fs';
				className: 'ConfigurationOfFilesystem';
				file: 'ConfigurationOfFilesystem' ].
		spec package: 'Ice-Core' with: [
			spec requires: #('FileSystem') ].
		spec package: 'Ice-Tests' with: [ 
			spec requires: 'Ice-Core' ]. 
		spec package: 'Ice-Glamour' with: [
			spec requires: #('Glamour' 'Ice-Core') ].
		
		spec group: 'Core' with: #('Ice-Core').
		spec group: 'Tests' with: #('Ice-Tests').
		spec group: 'GlamourGUI' with: #('Ice-Glamour').
		spec group: 'ALL' with: #('Core' 'Tests' 'GlamourGUI').
		spec group: 'default' with: #('Core' 'Tests') ].! !

!ConfigurationOfIce methodsFor: 'accessing' stamp: 'EstebanLorenzano 2/2/2011 15:44'!
password 
	^password ifNil: [ password := UIManager default requestPassword: 'Password' ]! !

!ConfigurationOfIce methodsFor: 'accessing' stamp: 'EstebanLorenzano 2/2/2011 15:44'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfIce methodsFor: 'accessing' stamp: 'DeboraFortini 2/12/2012 19:31'!
stable: spec 
       <symbolicVersion: #stable>
       
       spec for: #'pharo1.3.x' version: '0.3'. 
! !

!ConfigurationOfIce methodsFor: 'accessing' stamp: 'EstebanLorenzano 2/2/2011 15:44'!
username 
	^username ifNil: [ username := UIManager default request: 'User name' ]! !

!ConfigurationOfIce methodsFor: 'baselines' stamp: 'DeboraFortini 2/12/2012 19:01'!
version03: spec
	<version: '0.3' imports: #('0.3-baseline')>
	
	spec for: #'pharo1.3.x' do: [
		spec blessing: #beta.
		
		spec package: 'Ice-Core' with: 'Ice-Core-DeboraFortini.18'.
		spec package: 'Ice-Tests' with: 'Ice-Tests-DeboraFortini.12'.
		spec package: 'Ice-Glamour' with:  'Ice-Glamour-DeboraFortini.8'.
	].		
! !
